@@ -4,9 +4,21 @@
 
 #{{{ session
 
+configure_user(){
+    local -r grps="users,lp,video,network,storage,wheel,audio,power,log,optical,network,scanner"
+
+    chroot "$1" useradd -m -G "$grps" -s /bin/bash "${LIVEUSER}"
+    echo "${LIVEUSER}:${PASSWORD}" | chroot "$1" chpasswd
+    echo "root:${PASSWORD}" | chroot "$1" chpasswd
+}
+
 configure_services(){
     local mnt="$1"
-    add_svc_"${INITSYS}" "$mnt" "${SERVICES[*]}"
+    add_svc_"${INITSYS}" "$mnt"
+
+    if [[ "${INITSYS}" == "openrc" ]] || [[ "${INITSYS}" == "dinit" ]]; then
+        add_user_svc_"${INITSYS}" "$mnt"
+    fi
 }
 
 
@@ -14,13 +26,14 @@ write_live_session_conf(){
     local conf=''
     conf+=$(printf '%s\n' '# live session configuration')
     conf+=$(printf "\nAUTOLOGIN=%s\n" "${AUTOLOGIN}")
-    conf+=$(printf "\nPASSWORD=%s\n" "${PASSWORD}")
+    conf+=$(printf "\nLIVEUSER=%s\n" "${LIVEUSER}")
     printf '%s' "$conf"
 }
 
 configure_chroot(){
     local fs="$1"
     msg "Configuring [%s]" "${fs##*/}"
+    configure_user "$fs"
     configure_services "$fs"
     configure_calamares "$fs"
     [[ ! -d "$fs/etc/artools" ]] && mkdir -p "$fs/etc/artools"
